@@ -1,8 +1,9 @@
 use cosmwasm_std::Coin;
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
+use std::fmt;
 
-use cw0::NativeBalance;
+use cw_utils::NativeBalance;
 
 use crate::Cw20CoinVerified;
 
@@ -19,6 +20,16 @@ impl Default for Balance {
     }
 }
 
+impl fmt::Display for Balance {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        match self {
+            Balance::Native(native) => write!(f, "{}", native),
+            Balance::Cw20(cw20) => write!(f, "{}", cw20),
+        }?;
+        Ok(())
+    }
+}
+
 impl Balance {
     pub fn is_empty(&self) -> bool {
         match self {
