@@ -25,7 +25,7 @@ impl Cw20ReceiveMsg {
         let execute = WasmMsg::Execute {
             contract_addr: contract_addr.into(),
             msg,
-            send: vec![],
+            funds: vec![],
         };
         Ok(execute.into())
     }
